drop view if exists view_vaccination_rate_rki_sachsen_germany_weekly;
create view view_vaccination_rate_rki_sachsen_germany_weekly as
select case 
			when LENGTH(r.nr) = 4 then cast(cast(right(r.nr, 2) as integer)*1000 as varchar) 
			else right(r.nr, 5) 
			end as region, 
	   d.data_date as "date",
	   d.cases / cast(r.population as decimal) as rate_vaccine
	from datavalues d
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id  
	join region_types rt on r.region_type_id = rt.id
	where tt.timeperiod_type like 'Weekly' 
		and (
				(
				r.id > 7050 
				and r.id < 7064 
				and dt.datavalues_type like 'second_vaccinated'
				)
			or (
				r.id = 6696 
				and dt.datavalues_type like 'second_vaccinated_sum'
				)
			)
	order by r.nr, d.data_date ;

drop view if exists view_vaccination_rate_rki_sachsen_germany_weekly_cumsum;
create view view_vaccination_rate_rki_sachsen_germany_weekly_cumsum as
select vaccine_id.region, 
		vaccine_id."date",
		sum(rate_vaccine) over (partition by vaccine_id.region order by vaccine_id.id) as cumsum_ratevaccine
	from 
	(select row_number() over (order by r.nr, d.data_date) as id, 
			case 
				when LENGTH(r.nr) = 4 then cast(cast(right(r.nr, 2) as integer)*1000 as varchar) 
				else right(r.nr, 5) 
				end as region, 
		   d.data_date as "date",
		   d.cases / cast(r.population as decimal) as rate_vaccine
		from datavalues d
		inner join datavalues_types dt on d.datavalue_type_id = dt.id
		join timeperiod_types tt on d.timeperiod_type_id = tt.id 
		join regions r on d.region_id = r.id  
		join region_types rt on r.region_type_id = rt.id
		where tt.timeperiod_type like 'Weekly' 
			and (
					(
					r.id > 7050 
					and r.id < 7064 
					and dt.datavalues_type like 'second_vaccinated'
					)
				or (
					r.id = 6696 
					and dt.datavalues_type like 'second_vaccinated_sum'
					)
				)
		order by r.nr, d.data_date) as vaccine_id;

drop view if exists view_vaccination_rki_sachsen_germany_weekly_cumsum;
create view view_vaccination_rki_sachsen_germany_weekly_cumsum as
select vaccine_id.region, 
		vaccine_id."date",
		sum(vaccinated) over (partition by vaccine_id.region order by vaccine_id.id) as cumsum_vaccine,
		vaccine_id.population as population
	from 
	(select row_number() over (order by r.nr, d.data_date) as id, 
			case 
				when LENGTH(r.nr) = 4 then cast(cast(right(r.nr, 2) as integer)*1000 as varchar) 
				else right(r.nr, 5) 
				end as region, 
		   d.data_date as "date",
		   d.cases as vaccinated,
		   r.population as population
		from datavalues d
		inner join datavalues_types dt on d.datavalue_type_id = dt.id
		join timeperiod_types tt on d.timeperiod_type_id = tt.id 
		join regions r on d.region_id = r.id  
		join region_types rt on r.region_type_id = rt.id
		where tt.timeperiod_type like 'Weekly' 
			and (
					(
					r.id > 7050 
					and r.id < 7064 
					and dt.datavalues_type like 'second_vaccinated'
					)
				or (
					r.id = 6696 
					and dt.datavalues_type like 'second_vaccinated_sum'
					)
				)
		order by r.nr, d.data_date) as vaccine_id;

drop view if exists view_Chemnitz_secondVaccinated_daily;
create view view_Chemnitz_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like '%Chemnitz%'
		and d.time_period like 'Daily'
		order by data_date;

drop view if exists view_Erzgebirgskreis_secondVaccinated_daily;
create view view_Erzgebirgskreis_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like '%Erzgebirgskreis%'
		and d.time_period like 'Daily'
		order by data_date;

drop view if exists view_Mittelsachsen_secondVaccinated_daily;
create view view_Mittelsachsen_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like '%Mittelsachsen%'
		and d.time_period like 'Daily'
		order by data_date;

drop view if exists view_Vogtlandkreis_secondVaccinated_daily;
create view view_Vogtlandkreis_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like '%Vogtlandkreis%'
		and d.time_period like 'Daily'
		order by data_date;

drop view if exists view_Zwickau_secondVaccinated_daily;
create view view_Zwickau_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like '%Zwickau%'
		and d.time_period like 'Daily'
		order by data_date;

drop view if exists view_Dresden_secondVaccinated_daily;
create view view_Dresden_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like '%Dresden%'
		and d.time_period like 'Daily'
		order by data_date;

drop view if exists view_Bautzen_secondVaccinated_daily;
create view view_Bautzen_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like '%Bautzen%'
		and d.time_period like 'Daily'
		order by data_date;

drop view if exists view_Goerlitz_secondVaccinated_daily;
create view view_Goerlitz_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like '%G�rlitz%'
		and d.time_period like 'Daily'
		order by data_date;

drop view if exists view_Meissen_secondVaccinated_daily;
create view view_Meissen_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like '%Mei�en%'
		and d.time_period like 'Daily'
		order by data_date;

drop view if exists view_SaechsischeSchweizOsterzgebirge_secondVaccinated_daily;
create view view_SaechsischeSchweizOsterzgebirge_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like '%S�chsische Schweiz-Osterzgebirge%'
		and d.time_period like 'Daily'
		order by data_date;

drop view if exists view_Leipzig_secondVaccinated_daily;
create view view_Leipzig_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like 'Leipzig'
		and d.time_period like 'Daily'
		order by data_date;

drop view if exists view_LandkreisLeipzig_secondVaccinated_daily;
create view view_LandkreisLeipzig_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like 'Landkreis Leipzig'
		and d.time_period like 'Daily'
		order by data_date;

drop view if exists view_Nordsachsen_secondVaccinated_daily;
create view view_Nordsachsen_secondVaccinated_daily as
select 
	r.full_name as name_kreis, 
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as second_vaccinated, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'second_vaccinated' 
		and rt.region_type like '%Kreis%'
		and r.full_name like '%Nordsachsen%'
		and d.time_period like 'Daily'
		order by data_date;


