-- Drop table
DROP TABLE IF EXISTS public.region_types CASCADE;

CREATE TABLE public.region_types (
	id integer PRIMARY KEY NOT NULL,
	region_type varchar NOT NULL
);

COMMENT ON COLUMN public.region_types.id IS 'ID of region type';
COMMENT ON COLUMN public.region_types.region_type IS 'Type of region';

-- Drop table

DROP TABLE IF EXISTS public.regions CASCADE;

CREATE TABLE public.regions (
	id integer PRIMARY KEY NOT NULL,
	full_name varchar NOT NULL,
	short_name varchar NULL,
	abbreviation varchar NULL,
	nr varchar NOT NULL,
	region_type_id integer NOT NULL,
	geometry text NULL,
	population integer NULL,
	FOREIGN KEY (region_type_id) REFERENCES public.region_types (id) 
);

COMMENT ON COLUMN public.regions.id IS 'ID of regions';
COMMENT ON COLUMN public.regions.full_name IS 'Full name';
COMMENT ON COLUMN public.regions.short_name IS 'Short name';
COMMENT ON COLUMN public.regions.abbreviation IS 'Abbreviation';
COMMENT ON COLUMN public.regions.nr IS 'Number of regions';
COMMENT ON COLUMN public.regions.region_type_id IS 'ID of region type';
COMMENT ON COLUMN public.regions.geometry IS 'Geometry of region';
COMMENT ON COLUMN public.regions.population IS 'Number of populations';

-- Drop table
DROP TABLE IF EXISTS public.timeperiod_types CASCADE;

CREATE TABLE public.timeperiod_types (
	id integer PRIMARY KEY NOT NULL,
	timeperiod_type varchar NOT NULL
);

COMMENT ON COLUMN public.timeperiod_types.id IS 'ID for type of time period';
COMMENT ON COLUMN public.timeperiod_types.timeperiod_type IS 'Type of time period';

-- Drop table

DROP TABLE IF EXISTS public.datavalues_types CASCADE;

CREATE TABLE public.datavalues_types (
	id integer PRIMARY KEY NOT NULL,
	datavalues_type varchar NOT NULL
);

COMMENT ON COLUMN public.datavalues_types.id IS 'ID of case types';
COMMENT ON COLUMN public.datavalues_types.datavalues_type IS 'Type of cases, e.g., death, infected, tested, negative tested, positive test';

-- Drop table

DROP TABLE IF EXISTS public.dataValues CASCADE;

CREATE TABLE public.dataValues (
	id integer PRIMARY KEY NOT NULL,
	region_id integer NOT NULL,
	data_date date NOT NULL,
	modified_date date NOT NULL,
	cases integer NOT NULL,
	datavalue_type_id integer NOT NULL,
	time_period varchar NOT NULL,
	timeperiod_type_id integer NOT NULL,
	FOREIGN KEY (region_id) REFERENCES public.regions (id),
	FOREIGN KEY (datavalue_type_id) REFERENCES public.datavalues_types (id),
	FOREIGN KEY (timeperiod_type_id) REFERENCES public.timeperiod_types(id)
);

COMMENT ON COLUMN public.dataValues.region_id IS 'ID of regions';
COMMENT ON COLUMN public.dataValues.data_date IS 'Date of added data';
COMMENT ON COLUMN public.dataValues.modified_date IS 'Date of modified data';
COMMENT ON COLUMN public.dataValues.cases IS 'Number of cases';
COMMENT ON COLUMN public.dataValues.datavalue_type_id IS 'ID of case type';

DROP TABLE IF EXISTS public.dataValues_czech CASCADE;

CREATE TABLE public.dataValues_czech (
	id integer PRIMARY KEY NOT NULL,
	region_id integer NOT NULL,
	data_date date NOT NULL,
	modified_date date NOT NULL,
	cases integer NOT NULL,
	datavalue_type_id integer NOT NULL,
	time_period varchar NOT NULL,
	timeperiod_type_id integer NOT NULL,
	FOREIGN KEY (region_id) REFERENCES public.regions (id),
	FOREIGN KEY (datavalue_type_id) REFERENCES public.datavalues_types (id),
	FOREIGN KEY (timeperiod_type_id) REFERENCES public.timeperiod_types(id)
);

COMMENT ON COLUMN public.dataValues_czech.region_id IS 'ID of regions';
COMMENT ON COLUMN public.dataValues_czech.data_date IS 'Date of added data';
COMMENT ON COLUMN public.dataValues_czech.modified_date IS 'Date of modified data';
COMMENT ON COLUMN public.dataValues_czech.cases IS 'Number of cases';
COMMENT ON COLUMN public.dataValues_czech.datavalue_type_id IS 'ID of case type';

DROP TABLE IF EXISTS public.dataValues_poland CASCADE;

CREATE TABLE public.dataValues_poland (
	id integer PRIMARY KEY NOT NULL,
	region_id integer NOT NULL,
	data_date date NOT NULL,
	modified_date date NOT NULL,
	cases integer NOT NULL,
	datavalue_type_id integer NOT NULL,
	time_period varchar NOT NULL,
	timeperiod_type_id integer NOT NULL,
	FOREIGN KEY (region_id) REFERENCES public.regions (id),
	FOREIGN KEY (datavalue_type_id) REFERENCES public.datavalues_types (id),
	FOREIGN KEY (timeperiod_type_id) REFERENCES public.timeperiod_types(id)
);

COMMENT ON COLUMN public.dataValues_poland.region_id IS 'ID of regions';
COMMENT ON COLUMN public.dataValues_poland.data_date IS 'Date of added data';
COMMENT ON COLUMN public.dataValues_poland.modified_date IS 'Date of modified data';
COMMENT ON COLUMN public.dataValues_poland.cases IS 'Number of cases';
COMMENT ON COLUMN public.dataValues_poland.datavalue_type_id IS 'ID of case type';

DROP TABLE IF EXISTS public.dataValues_wwm CASCADE;

CREATE TABLE public.dataValues_wwm (
	id integer PRIMARY KEY NOT NULL,
	region_id integer NOT NULL,
	data_date date NOT NULL,
	modified_date date NOT NULL,
	ct1 real NULL,
	ct2 real NULL,
	ct_mittelwert real NULL,
	hydraulische_last integer NULL,
	klaeranlagegroesse integer NULL,
	datavalue_type_id integer NOT NULL,
	time_period varchar NOT NULL,
	timeperiod_type_id integer NOT NULL,
	FOREIGN KEY (region_id) REFERENCES public.regions (id),
	FOREIGN KEY (datavalue_type_id) REFERENCES public.datavalues_types (id),
	FOREIGN KEY (timeperiod_type_id) REFERENCES public.timeperiod_types(id)
);

COMMENT ON COLUMN public.dataValues_wwm.region_id IS 'ID of regions';
COMMENT ON COLUMN public.dataValues_wwm.data_date IS 'Date of added data';
COMMENT ON COLUMN public.dataValues_wwm.modified_date IS 'Date of modified data';
COMMENT ON COLUMN public.dataValues_wwm.ct1 IS 'CT 1';
COMMENT ON COLUMN public.dataValues_wwm.ct2 IS 'CT 2';
COMMENT ON COLUMN public.dataValues_wwm.ct_mittelwert IS 'CT Median';
COMMENT ON COLUMN public.dataValues_wwm.datavalue_type_id IS 'ID of case type';
-- Drop table

DROP TABLE IF EXISTS public.mapping_types CASCADE;

CREATE TABLE public.mapping_types (
	id integer PRIMARY KEY NOT NULL,
	mapping_type varchar NOT NULL
);

COMMENT ON COLUMN public.mapping_types.id IS 'Type ID of Mapping between regions';
COMMENT ON COLUMN public.mapping_types.mapping_type IS 'Type of Mapping between regions';

-- Drop table

DROP TABLE IF EXISTS public.mapping_regions CASCADE;

CREATE TABLE public.mapping_regions (
	id integer PRIMARY KEY NOT NULL,
	fromregion_id integer  NOT NULL,
	toregion_id integer  NOT NULL,
	mapping_type_id integer NOT null,
	FOREIGN KEY (fromregion_id) REFERENCES public.regions (id),
	FOREIGN KEY (toregion_id) REFERENCES public.regions (id),
	FOREIGN KEY (mapping_type_id) REFERENCES public.mapping_types (id)
);

COMMENT ON COLUMN public.mapping_regions.id IS 'ID of Mapping between regions';
COMMENT ON COLUMN public.mapping_regions.fromregion_id IS 'ID of mapped region';
COMMENT ON COLUMN public.mapping_regions.toregion_id IS 'ID of region which consists of mapped regions';
COMMENT ON COLUMN public.mapping_regions.mapping_type_id IS 'ID of mapping type';