drop view if exists view_Germany_infected_weekly cascade;
create view view_Germany_infected_weekly AS
select 
	r.full_name as name_country,
	r.nr as nr_country,
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as infected, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'infected' 
		and rt.region_type like '%Countries_EU%'
		and d.time_period like 'Weekly'
		order by data_date;
		

drop view if exists view_Germany_infected_men_weekly cascade;
create view view_Germany_infected_men_weekly as
select 
	r.full_name as name_country,
	r.nr as nr_country,
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as infected, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'infected_men' 
		and rt.region_type like '%Countries_EU%'
		and d.time_period like 'Weekly'
		order by data_date;
		
drop view if exists view_Germany_infected_women_weekly cascade;
create view view_Germany_infected_women_weekly as
select 
	r.full_name as name_country,
	r.nr as nr_country,
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as infected, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'infected_women' 
		and rt.region_type like '%Countries_EU%'
		and d.time_period like 'Weekly'
		order by data_date;

drop view if exists view_Germany_infected_with_symptomp_weekly cascade;
create view view_Germany_infected_with_symptomp_weekly as
select 
	r.full_name as name_country,
	r.nr as nr_country,
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as infected, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'infected_with_symptom' 
		and rt.region_type like '%Countries_EU%'
		and d.time_period like 'Weekly'
		order by data_date;
		
drop view if exists view_Germany_infected_hospitalized_indicated_weekly cascade;
create view view_Germany_infected_hospitalized_indicated_weekly as
select 
	r.full_name as name_country,
	r.nr as nr_country,
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as infected, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'infected_hospitalized_indicated' 
		and rt.region_type like '%Countries_EU%'
		and d.time_period like 'Weekly'
		order by data_date;
		
drop view if exists view_Germany_infected_hospitalized_weekly cascade;
create view view_Germany_infected_hospitalized_weekly as
select 
	r.full_name as name_country,
	r.nr as nr_country,
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as infected, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'infected_hospitalized' 
		and rt.region_type like '%Countries_EU%'
		and d.time_period like 'Weekly'
		order by data_date;
		
drop view if exists view_Germany_dead_hospitalized_weekly cascade;
create view view_Germany_dead_hospitalized_weekly as
select 
	r.full_name as name_country,
	r.nr as nr_country,
	d.data_date as date_input, 
	d.modified_date as modified_date, 
	d.cases as dead, 
	r.population as population 
	from datavalues d 
	inner join datavalues_types dt on d.datavalue_type_id = dt.id
	join timeperiod_types tt on d.timeperiod_type_id = tt.id 
	join regions r on d.region_id = r.id 
	join region_types rt on r.region_type_id = rt.id
	where 
		dt.datavalues_type like 'dead' 
		and rt.region_type like '%Countries_EU%'
		and d.time_period like 'Weekly'
		order by data_date;

drop view if exists view_Germany_klinische_aspekte cascade;
create view view_Germany_klinische_aspekte as
select 
		vgiw.name_country as country_name,
		vgiw.date_input as date_input,
		vgiw.modified_date as modified_date,
		vgiw.infected as infected,
		vgimw.infected as infected_men,
		vgiww.infected as infected_women,
		vgiwsw.infected as infected_symtomp,
		vgihiw.infected as infected_hospital_indicated,
		vgihw.infected as infected_hospitalized,
		vgdhw.dead as dead_hospitalized
		from view_germany_infected_weekly vgiw
		inner join view_germany_infected_men_weekly vgimw on vgiw.date_input = vgimw.date_input
		inner join view_germany_infected_women_weekly vgiww on vgimw.date_input = vgiww.date_input
		inner join view_germany_infected_with_symptomp_weekly vgiwsw on vgiww.date_input = vgiwsw.date_input
		inner join view_germany_infected_hospitalized_indicated_weekly vgihiw on vgiwsw.date_input = vgihiw.date_input
		inner join view_germany_infected_hospitalized_weekly vgihw on vgihiw.date_input = vgihw.date_input
		inner join view_germany_dead_hospitalized_weekly vgdhw on vgihw.date_input = vgdhw.date_input; 
		