--
-- @file 
--      domain.schema.sql
-- @description
--      Domain schema definition 
-- ==========================================================================

-- ----------------------------------------------------------------------------
-- @table META_GENERIC_OBJECTS
-- ----------------------------------------------------------------------------
-- DROP TABLE META_GENERIC_OBJECTS;

CREATE TABLE IF NOT EXISTS META_GENERIC_OBJECTS (
	ID BIGINT auto_increment,
	SOURCE_NAME VARCHAR(255) NOT NULL,
	SOURCE_GENERATOR VARCHAR(255) NOT NULL,
	OBJECT_TYPE_NAME VARCHAR(255) NOT NULL,
	OBJECT_ENTITY_ID VARCHAR(320) NOT NULL,
	STATUS ENUM('valid', 'removed', 'deprecated'),
	DATE_CREATED TIMESTAMP NOT NULL DEFAULT CURRENT_DATE,
	DATE_CHANGED TIMESTAMP NOT NULL DEFAULT CURRENT_DATE,
	CONSTRAINT PK_META_GENERIC_OBJECTS PRIMARY KEY (ID)
	);

CREATE UNIQUE INDEX IF NOT EXISTS IDX_NAME ON META_GENERIC_OBJECTS (
	SOURCE_NAME,
	OBJECT_TYPE_NAME,
	OBJECT_ENTITY_ID
	);

-- ----------------------------------------------------------------------------
-- @table META_SOURCES
-- ----------------------------------------------------------------------------
-- DROP TABLE META_SOURCES;

CREATE TABLE IF NOT EXISTS META_SOURCES (
	ID BIGINT auto_increment,
	NAME VARCHAR(255) NOT NULL,
	DESCRIPTION VARCHAR(1024),
	CONSTRAINT PK_META_SOURCES PRIMARY KEY (ID)
	);

CREATE UNIQUE INDEX IF NOT EXISTS IDX_NAME ON META_SOURCES (
	`NAME`
	);

-- ----------------------------------------------------------------------------
-- @table META_OBJECT_TYPES
-- ----------------------------------------------------------------------------
-- DROP TABLE META_OBJECT_TYPES;

CREATE TABLE IF NOT EXISTS META_OBJECT_TYPES (
	ID BIGINT auto_increment,
	NAME VARCHAR(255) NOT NULL,
	DESCRIPTION VARCHAR(1024),
	CONSTRAINT PK_META_OBJECT_TYPES PRIMARY KEY (ID)
	);

CREATE UNIQUE INDEX IF NOT EXISTS IDX_NAME ON META_OBJECT_TYPES (
	`NAME`
	);

-- ----------------------------------------------------------------------------
-- @table META_CATEGORIES
-- ----------------------------------------------------------------------------
-- DROP TABLE META_CATEGORIES;

CREATE TABLE IF NOT EXISTS META_CATEGORIES (
	ID BIGINT auto_increment,
	NAME VARCHAR(255) NOT NULL,
	DESCRIPTION VARCHAR(1024),
	CONSTRAINT PK_META_CATEGORIES PRIMARY KEY (ID)
	);

CREATE UNIQUE INDEX IF NOT EXISTS IDX_NAME ON META_CATEGORIES (
	`NAME`
	);

-- ----------------------------------------------------------------------------
-- @table META_GENERIC_OBJECT_CATEGORIES
-- ----------------------------------------------------------------------------
-- DROP TABLE META_GENERIC_OBJECT_CATEGORIES;

CREATE TABLE IF NOT EXISTS META_GENERIC_OBJECT_CATEGORIES (
	OBJECT_TYPE_NAME VARCHAR(255) NOT NULL,
	OBJECT_ENTITY_ID VARCHAR(320) NOT NULL,
	CATEGORY_NAME VARCHAR(255) NOT NULL,
	CONSTRAINT PK_META_GENERIC_OBJECT_CATEGORIES PRIMARY KEY (OBJECT_TYPE_NAME, OBJECT_ENTITY_ID, CATEGORY_NAME)
	);

-- ----------------------------------------------------------------------------
-- @constraint FK_META_GENERIC_OBJECTS_SOURCES
-- @table META_GENERIC_OBJECTS
-- ----------------------------------------------------------------------------
-- DROP CONSTRAINT FK_META_GENERIC_OBJECTS_SOURCES;

ALTER TABLE META_GENERIC_OBJECTS
	ADD CONSTRAINT IF NOT EXISTS FK_META_GENERIC_OBJECTS_SOURCES
	FOREIGN KEY (SOURCE_NAME) 
	REFERENCES META_SOURCES(NAME)
	ON DELETE CASCADE
	;

-- ----------------------------------------------------------------------------
-- @constraint FK_META_GENERIC_OBJECT_TYPES
-- @table META_GENERIC_OBJECTS
-- ----------------------------------------------------------------------------

ALTER TABLE META_GENERIC_OBJECTS
	ADD CONSTRAINT IF NOT EXISTS FK_META_GENERIC_OBJECT_TYPES
	FOREIGN KEY (OBJECT_TYPE_NAME) 
	REFERENCES META_OBJECT_TYPES(NAME)
	ON DELETE CASCADE
	;

-- ----------------------------------------------------------------------------
-- @constraint FK_META_GENERIC_OBJECT_CATEGORIES_GENERIC_OBJECTS
-- @table META_GENERIC_OBJECT_CATEGORIES
-- ----------------------------------------------------------------------------

ALTER TABLE META_GENERIC_OBJECT_CATEGORIES
	ADD CONSTRAINT IF NOT EXISTS FK_META_GENERIC_OBJECT_CATEGORIES_GENERIC_OBJECTS
	FOREIGN KEY (
		OBJECT_TYPE_NAME,
		OBJECT_ENTITY_ID
		) 
	REFERENCES META_GENERIC_OBJECTS(
		OBJECT_TYPE_NAME,
		OBJECT_ENTITY_ID
		)
	ON DELETE CASCADE
	;

-- ----------------------------------------------------------------------------
-- @constraint FK_META_GENERIC_OBJECT_CATEGORIES_CATEGORIES
-- @table META_GENERIC_OBJECT_CATEGORIES
-- ----------------------------------------------------------------------------

ALTER TABLE META_GENERIC_OBJECT_CATEGORIES
	ADD CONSTRAINT IF NOT EXISTS FK_META_GENERIC_OBJECT_CATEGORIES_CATEGORIES
	FOREIGN KEY (
		CATEGORY_NAME
		) 
	REFERENCES META_CATEGORIES(
		NAME
		)
	ON DELETE CASCADE
	;

-- ----------------------------------------------------------------------------
-- @constraint FK_META_GENERIC_OBJECT_CATEGORIES_CATEGORIES
-- @table META_GENERIC_OBJECT_CATEGORIES
-- ----------------------------------------------------------------------------

CREATE OR REPLACE VIEW VIEW_META_GENERIC_OBJECT_CATEGORIES AS
SELECT 
	mgo.ID
		AS OBJECT_ID,
	mgo.OBJECT_ENTITY_ID
		AS ENTITY_ID,
	mgo.OBJECT_TYPE_NAME
		AS ENTITY_TYPE,
	mgo.SOURCE_NAME
		AS SOURCE_NAME,
	mgo.SOURCE_GENERATOR
		AS SOURCE_GENERATOR,
	mgo.STATUS
		AS STATUS,
	mgoc.CATEGORY_NAME
		AS CATEGORY
	FROM
		META_GENERIC_OBJECTS mgo 
		JOIN META_GENERIC_OBJECT_CATEGORIES mgoc ON 
			mgoc.OBJECT_TYPE_NAME = mgo.OBJECT_TYPE_NAME 
			AND 
			mgoc.OBJECT_ENTITY_ID = mgo.OBJECT_ENTITY_ID
			;
