--
-- @file 
--      domain.schema.sql
-- @description
--      Domain schema definition 
-- ==========================================================================

-- ----------------------------------------------------------------------------
-- @table META_GENERIC_OBJECTS
-- ----------------------------------------------------------------------------
DROP TABLE META_GENERIC_OBJECTS IF EXISTS CASCADE;

CREATE TABLE IF NOT EXISTS META_GENERIC_OBJECTS (
	ID BIGINT auto_increment,
	SOURCE_NAME VARCHAR(255) NOT NULL,
	SOURCE_GENERATOR VARCHAR(255) NOT NULL,
	OBJECT_TYPE_NAME VARCHAR(255) NOT NULL,
	OBJECT_ENTITY_ID VARCHAR(320) NOT NULL,
	STATUS ENUM('valid', 'removed', 'deprecated'),
	DATE_CREATED TIMESTAMP NOT NULL DEFAULT CURRENT_DATE,
	DATE_CHANGED TIMESTAMP NOT NULL DEFAULT CURRENT_DATE,
	CONSTRAINT PK_META_GENERIC_OBJECTS PRIMARY KEY (ID)
	);

CREATE UNIQUE INDEX IF NOT EXISTS IDX_NAME ON META_GENERIC_OBJECTS (
	SOURCE_NAME,
	OBJECT_TYPE_NAME--,
	--OBJECT_ENTITY_ID
	);

-- ----------------------------------------------------------------------------
-- @table META_SOURCES
-- ----------------------------------------------------------------------------
DROP TABLE META_SOURCES IF EXISTS CASCADE;

CREATE TABLE IF NOT EXISTS META_SOURCES (
	ID BIGINT auto_increment,
	NAME VARCHAR(255) NOT NULL,
	DESCRIPTION VARCHAR(1024),
	CONSTRAINT PK_META_SOURCES PRIMARY KEY (ID)
	);

CREATE UNIQUE INDEX IF NOT EXISTS IDX_NAME ON META_SOURCES (
	`NAME`
	);

-- ----------------------------------------------------------------------------
-- @table META_OBJECT_TYPES
-- ----------------------------------------------------------------------------
DROP TABLE META_OBJECT_TYPES IF EXISTS CASCADE;

CREATE TABLE IF NOT EXISTS META_OBJECT_TYPES (
	ID BIGINT auto_increment,
	NAME VARCHAR(255) NOT NULL,
	DESCRIPTION VARCHAR(1024),
	CONSTRAINT PK_META_OBJECT_TYPES PRIMARY KEY (ID)
	);

CREATE UNIQUE INDEX IF NOT EXISTS IDX_NAME ON META_OBJECT_TYPES (
	`NAME`
	);

-- ----------------------------------------------------------------------------
-- @table META_CATEGORIES
-- ----------------------------------------------------------------------------
DROP TABLE META_CATEGORIES IF EXISTS CASCADE;

CREATE TABLE IF NOT EXISTS META_CATEGORIES (
	ID BIGINT auto_increment,
	NAME VARCHAR(255) NOT NULL,
	DESCRIPTION VARCHAR(1024),
	CONSTRAINT PK_META_CATEGORIES PRIMARY KEY (ID)
	);

CREATE UNIQUE INDEX IF NOT EXISTS IDX_NAME ON META_CATEGORIES (
	`NAME`
	);


-- ----------------------------------------------------------------------------
-- @table META_OBJECT_MAPPING
-- ----------------------------------------------------------------------------
-- DROP TABLE META_CATEGORIES;
DROP TABLE META_OBJECT_MAPPING IF EXISTS CASCADE;
CREATE TABLE IF NOT EXISTS  META_OBJECT_MAPPING (
	ID BIGINT auto_increment,
	SOURCE_ID BIGINT NOT NULL,
	SOURCE_NAME VARCHAR(255) NOT NULL,
	SOURCE_TYPE VARCHAR(255) NOT NULL,
	TARGET_ID BIGINT NOT NULL,
	TARGET_NAME VARCHAR(255) NOT NULL,
	TARGET_TYPE VARCHAR(255) NOT NULL,
	TABLE_NAME VARCHAR(255) NOT NULL,
	DESCRIPTION VARCHAR(1024),
	CONSTRAINT PK_META_OBJECT_MAPPING PRIMARY KEY (ID)
	);

CREATE UNIQUE INDEX IF NOT EXISTS IDX_META_OBJECT_MAPPING_NAME ON META_OBJECT_MAPPING (
	SOURCE_ID,
	TARGET_ID,
	TABLE_NAME
	);

-----------------------------------------------------------------------------
-- @table META_CONTACT_MAPPING
-- ----------------------------------------------------------------------------
DROP TABLE META_CONTACT_MAPPING IF EXISTS CASCADE;
CREATE TABLE IF NOT EXISTS  META_CONTACT_MAPPING (
	ID BIGINT auto_increment,
	SOURCE_ID BIGINT NOT NULL,
	SOURCE_NAME VARCHAR(255) NOT NULL,
	SOURCE_TYPE VARCHAR(255) NOT NULL,
	TARGET_ID BIGINT NOT NULL,
	TARGET_NAME VARCHAR(255) NOT NULL,
	TARGET_TYPE VARCHAR(255) NOT NULL,
	TABLE_NAME VARCHAR(255) NOT NULL,
	DESCRIPTION VARCHAR(1024),
	CONSTRAINT PK_META_CONTACT_MAPPING PRIMARY KEY (ID)
	);

CREATE UNIQUE INDEX IF NOT EXISTS IDX_META_CONTACT_MAPPING_NAME ON META_CONTACT_MAPPING (
	SOURCE_ID,
	TARGET_ID,
	TABLE_NAME
	);


-- ----------------------------------------------------------------------------
-- @table META_GENERIC_OBJECT_CATEGORIES
-- ----------------------------------------------------------------------------
DROP TABLE META_GENERIC_OBJECT_CATEGORIES IF EXISTS CASCADE;

CREATE TABLE IF NOT EXISTS META_GENERIC_OBJECT_CATEGORIES (
	OBJECT_TYPE_NAME VARCHAR(255) NOT NULL,
	OBJECT_ENTITY_ID VARCHAR(320) NOT NULL,
	CATEGORY_NAME VARCHAR(255) NOT NULL,
	CONSTRAINT PK_META_GENERIC_OBJECT_CATEGORIES PRIMARY KEY (OBJECT_TYPE_NAME, CATEGORY_NAME)
	--CONSTRAINT PK_META_GENERIC_OBJECT_CATEGORIES PRIMARY KEY (OBJECT_TYPE_NAME, OBJECT_ENTITY_ID, CATEGORY_NAME)
	);

CREATE TABLE IF NOT EXISTS ADDRESS_GROUP (
  contact_id BIGINT NOT NULL AUTO_INCREMENT,
  contact_tid varchar(1) DEFAULT 'n',
  contact_owner bigint(20) NOT NULL,
  contact_private tinyint(4) DEFAULT '0',
  cat_id varchar(255) DEFAULT NULL,
  n_family varchar(64) DEFAULT NULL,
  n_given varchar(64) DEFAULT NULL,
  n_middle varchar(64) DEFAULT NULL,
  n_prefix varchar(64) DEFAULT NULL,
  n_suffix varchar(64) DEFAULT NULL,
  n_fn varchar(128) DEFAULT NULL,
  n_fileas varchar(255) DEFAULT NULL,
  contact_bday varchar(12) DEFAULT NULL,
  org_name varchar(128) DEFAULT NULL,
  org_unit varchar(64) DEFAULT NULL,
  contact_title varchar(64) DEFAULT NULL,
  contact_role varchar(64) DEFAULT NULL,
  contact_assistent varchar(64) DEFAULT NULL,
  contact_room varchar(64) DEFAULT NULL,
  adr_one_street varchar(64) DEFAULT NULL,
  adr_one_street2 varchar(64) DEFAULT NULL,
  adr_one_locality varchar(64) DEFAULT NULL,
  adr_one_region varchar(64) DEFAULT NULL,
  adr_one_postalcode varchar(64) DEFAULT NULL,
  adr_one_countryname varchar(64) DEFAULT NULL,
  contact_label text,
  adr_two_street varchar(64) DEFAULT NULL,
  adr_two_street2 varchar(64) DEFAULT NULL,
  adr_two_locality varchar(64) DEFAULT NULL,
  adr_two_region varchar(64) DEFAULT NULL,
  adr_two_postalcode varchar(64) DEFAULT NULL,
  adr_two_countryname varchar(64) DEFAULT NULL,
  tel_work varchar(40) DEFAULT NULL,
  tel_cell varchar(40) DEFAULT NULL,
  tel_fax varchar(40) DEFAULT NULL,
  tel_assistent varchar(40) DEFAULT NULL,
  tel_car varchar(40) DEFAULT NULL,
  tel_pager varchar(40) DEFAULT NULL,
  tel_home varchar(40) DEFAULT NULL,
  tel_fax_home varchar(40) DEFAULT NULL,
  tel_cell_private varchar(40) DEFAULT NULL,
  tel_other varchar(40) DEFAULT NULL,
  tel_prefer varchar(32) DEFAULT NULL,
  contact_email varchar(128) DEFAULT NULL,
  contact_email_home varchar(128) DEFAULT NULL,
  contact_url varchar(128) DEFAULT NULL,
  contact_url_home varchar(128) DEFAULT NULL,
  contact_freebusy_uri varchar(128) DEFAULT NULL,
  contact_calendar_uri varchar(128) DEFAULT NULL,
  contact_note text,
  contact_tz varchar(8) DEFAULT NULL,
  contact_geo varchar(32) DEFAULT NULL,
  contact_pubkey text,
  contact_created bigint(20) DEFAULT NULL,
  contact_creator INTEGER NOT NULL,
  contact_modified bigint(20) NOT NULL,
  contact_modifier INTEGER DEFAULT NULL,
  contact_jpegphoto longtext,
  account_id INTEGER DEFAULT NULL,
  contact_etag INTEGER DEFAULT '0',
  contact_uid varchar(255) DEFAULT NULL,
  adr_one_countrycode varchar(2) DEFAULT NULL,
  adr_two_countrycode varchar(2) DEFAULT NULL,
  carddav_name varchar(64) DEFAULT NULL,
  PRIMARY KEY (contact_id)
);

CREATE TABLE IF NOT EXISTS ADDRESS_CREATEDBY_ROLAND (
  contact_id BIGINT NOT NULL AUTO_INCREMENT,
  contact_tid varchar(1) DEFAULT 'n',
  contact_owner bigint(20) NOT NULL,
  contact_private tinyint(4) DEFAULT '0',
  cat_id varchar(255) DEFAULT NULL,
  n_family varchar(64) DEFAULT NULL,
  n_given varchar(64) DEFAULT NULL,
  n_middle varchar(64) DEFAULT NULL,
  n_prefix varchar(64) DEFAULT NULL,
  n_suffix varchar(64) DEFAULT NULL,
  n_fn varchar(128) DEFAULT NULL,
  n_fileas varchar(255) DEFAULT NULL,
  contact_bday varchar(12) DEFAULT NULL,
  org_name varchar(128) DEFAULT NULL,
  org_unit varchar(64) DEFAULT NULL,
  contact_title varchar(64) DEFAULT NULL,
  contact_role varchar(64) DEFAULT NULL,
  contact_assistent varchar(64) DEFAULT NULL,
  contact_room varchar(64) DEFAULT NULL,
  adr_one_street varchar(64) DEFAULT NULL,
  adr_one_street2 varchar(64) DEFAULT NULL,
  adr_one_locality varchar(64) DEFAULT NULL,
  adr_one_region varchar(64) DEFAULT NULL,
  adr_one_postalcode varchar(64) DEFAULT NULL,
  adr_one_countryname varchar(64) DEFAULT NULL,
  contact_label text,
  adr_two_street varchar(64) DEFAULT NULL,
  adr_two_street2 varchar(64) DEFAULT NULL,
  adr_two_locality varchar(64) DEFAULT NULL,
  adr_two_region varchar(64) DEFAULT NULL,
  adr_two_postalcode varchar(64) DEFAULT NULL,
  adr_two_countryname varchar(64) DEFAULT NULL,
  tel_work varchar(40) DEFAULT NULL,
  tel_cell varchar(40) DEFAULT NULL,
  tel_fax varchar(40) DEFAULT NULL,
  tel_assistent varchar(40) DEFAULT NULL,
  tel_car varchar(40) DEFAULT NULL,
  tel_pager varchar(40) DEFAULT NULL,
  tel_home varchar(40) DEFAULT NULL,
  tel_fax_home varchar(40) DEFAULT NULL,
  tel_cell_private varchar(40) DEFAULT NULL,
  tel_other varchar(40) DEFAULT NULL,
  tel_prefer varchar(32) DEFAULT NULL,
  contact_email varchar(128) DEFAULT NULL,
  contact_email_home varchar(128) DEFAULT NULL,
  contact_url varchar(128) DEFAULT NULL,
  contact_url_home varchar(128) DEFAULT NULL,
  contact_freebusy_uri varchar(128) DEFAULT NULL,
  contact_calendar_uri varchar(128) DEFAULT NULL,
  contact_note text,
  contact_tz varchar(8) DEFAULT NULL,
  contact_geo varchar(32) DEFAULT NULL,
  contact_pubkey text,
  contact_created bigint(20) DEFAULT NULL,
  contact_creator INTEGER NOT NULL,
  contact_modified bigint(20) NOT NULL,
  contact_modifier INTEGER DEFAULT NULL,
  contact_jpegphoto longtext,
  account_id INTEGER DEFAULT NULL,
  contact_etag INTEGER DEFAULT '0',
  contact_uid varchar(255) DEFAULT NULL,
  adr_one_countrycode varchar(2) DEFAULT NULL,
  adr_two_countrycode varchar(2) DEFAULT NULL,
  carddav_name varchar(64) DEFAULT NULL,
  PRIMARY KEY (contact_id)
);

CREATE TABLE IF NOT EXISTS ADDRESS_CREATEDBY_CHRIS (
  contact_id BIGINT NOT NULL AUTO_INCREMENT,
  contact_tid varchar(1) DEFAULT 'n',
  contact_owner bigint(20) NOT NULL,
  contact_private tinyint(4) DEFAULT '0',
  cat_id varchar(255) DEFAULT NULL,
  n_family varchar(64) DEFAULT NULL,
  n_given varchar(64) DEFAULT NULL,
  n_middle varchar(64) DEFAULT NULL,
  n_prefix varchar(64) DEFAULT NULL,
  n_suffix varchar(64) DEFAULT NULL,
  n_fn varchar(128) DEFAULT NULL,
  n_fileas varchar(255) DEFAULT NULL,
  contact_bday varchar(12) DEFAULT NULL,
  org_name varchar(128) DEFAULT NULL,
  org_unit varchar(64) DEFAULT NULL,
  contact_title varchar(64) DEFAULT NULL,
  contact_role varchar(64) DEFAULT NULL,
  contact_assistent varchar(64) DEFAULT NULL,
  contact_room varchar(64) DEFAULT NULL,
  adr_one_street varchar(64) DEFAULT NULL,
  adr_one_street2 varchar(64) DEFAULT NULL,
  adr_one_locality varchar(64) DEFAULT NULL,
  adr_one_region varchar(64) DEFAULT NULL,
  adr_one_postalcode varchar(64) DEFAULT NULL,
  adr_one_countryname varchar(64) DEFAULT NULL,
  contact_label text,
  adr_two_street varchar(64) DEFAULT NULL,
  adr_two_street2 varchar(64) DEFAULT NULL,
  adr_two_locality varchar(64) DEFAULT NULL,
  adr_two_region varchar(64) DEFAULT NULL,
  adr_two_postalcode varchar(64) DEFAULT NULL,
  adr_two_countryname varchar(64) DEFAULT NULL,
  tel_work varchar(40) DEFAULT NULL,
  tel_cell varchar(40) DEFAULT NULL,
  tel_fax varchar(40) DEFAULT NULL,
  tel_assistent varchar(40) DEFAULT NULL,
  tel_car varchar(40) DEFAULT NULL,
  tel_pager varchar(40) DEFAULT NULL,
  tel_home varchar(40) DEFAULT NULL,
  tel_fax_home varchar(40) DEFAULT NULL,
  tel_cell_private varchar(40) DEFAULT NULL,
  tel_other varchar(40) DEFAULT NULL,
  tel_prefer varchar(32) DEFAULT NULL,
  contact_email varchar(128) DEFAULT NULL,
  contact_email_home varchar(128) DEFAULT NULL,
  contact_url varchar(128) DEFAULT NULL,
  contact_url_home varchar(128) DEFAULT NULL,
  contact_freebusy_uri varchar(128) DEFAULT NULL,
  contact_calendar_uri varchar(128) DEFAULT NULL,
  contact_note text,
  contact_tz varchar(8) DEFAULT NULL,
  contact_geo varchar(32) DEFAULT NULL,
  contact_pubkey text,
  contact_created bigint(20) DEFAULT NULL,
  contact_creator INTEGER NOT NULL,
  contact_modified bigint(20) NOT NULL,
  contact_modifier INTEGER DEFAULT NULL,
  contact_jpegphoto longtext,
  account_id INTEGER DEFAULT NULL,
  contact_etag INTEGER DEFAULT '0',
  contact_uid varchar(255) DEFAULT NULL,
  adr_one_countrycode varchar(2) DEFAULT NULL,
  adr_two_countrycode varchar(2) DEFAULT NULL,
  carddav_name varchar(64) DEFAULT NULL,
  PRIMARY KEY (contact_id)
);

CREATE TABLE IF NOT EXISTS ADDRESS_CREATEDBY_CUSTOMER (
  contact_id BIGINT NOT NULL AUTO_INCREMENT,
  contact_tid varchar(1) DEFAULT 'n',
  contact_owner bigint(20) NOT NULL,
  contact_private tinyint(4) DEFAULT '0',
  cat_id varchar(255) DEFAULT NULL,
  n_family varchar(64) DEFAULT NULL,
  n_given varchar(64) DEFAULT NULL,
  n_middle varchar(64) DEFAULT NULL,
  n_prefix varchar(64) DEFAULT NULL,
  n_suffix varchar(64) DEFAULT NULL,
  n_fn varchar(128) DEFAULT NULL,
  n_fileas varchar(255) DEFAULT NULL,
  contact_bday varchar(12) DEFAULT NULL,
  org_name varchar(128) DEFAULT NULL,
  org_unit varchar(64) DEFAULT NULL,
  contact_title varchar(64) DEFAULT NULL,
  contact_role varchar(64) DEFAULT NULL,
  contact_assistent varchar(64) DEFAULT NULL,
  contact_room varchar(64) DEFAULT NULL,
  adr_one_street varchar(64) DEFAULT NULL,
  adr_one_street2 varchar(64) DEFAULT NULL,
  adr_one_locality varchar(64) DEFAULT NULL,
  adr_one_region varchar(64) DEFAULT NULL,
  adr_one_postalcode varchar(64) DEFAULT NULL,
  adr_one_countryname varchar(64) DEFAULT NULL,
  contact_label text,
  adr_two_street varchar(64) DEFAULT NULL,
  adr_two_street2 varchar(64) DEFAULT NULL,
  adr_two_locality varchar(64) DEFAULT NULL,
  adr_two_region varchar(64) DEFAULT NULL,
  adr_two_postalcode varchar(64) DEFAULT NULL,
  adr_two_countryname varchar(64) DEFAULT NULL,
  tel_work varchar(40) DEFAULT NULL,
  tel_cell varchar(40) DEFAULT NULL,
  tel_fax varchar(40) DEFAULT NULL,
  tel_assistent varchar(40) DEFAULT NULL,
  tel_car varchar(40) DEFAULT NULL,
  tel_pager varchar(40) DEFAULT NULL,
  tel_home varchar(40) DEFAULT NULL,
  tel_fax_home varchar(40) DEFAULT NULL,
  tel_cell_private varchar(40) DEFAULT NULL,
  tel_other varchar(40) DEFAULT NULL,
  tel_prefer varchar(32) DEFAULT NULL,
  contact_email varchar(128) DEFAULT NULL,
  contact_email_home varchar(128) DEFAULT NULL,
  contact_url varchar(128) DEFAULT NULL,
  contact_url_home varchar(128) DEFAULT NULL,
  contact_freebusy_uri varchar(128) DEFAULT NULL,
  contact_calendar_uri varchar(128) DEFAULT NULL,
  contact_note text,
  contact_tz varchar(8) DEFAULT NULL,
  contact_geo varchar(32) DEFAULT NULL,
  contact_pubkey text,
  contact_created bigint(20) DEFAULT NULL,
  contact_creator INTEGER NOT NULL,
  contact_modified bigint(20) NOT NULL,
  contact_modifier INTEGER DEFAULT NULL,
  contact_jpegphoto longtext,
  account_id INTEGER DEFAULT NULL,
  contact_etag INTEGER DEFAULT '0',
  contact_uid varchar(255) DEFAULT NULL,
  adr_one_countrycode varchar(2) DEFAULT NULL,
  adr_two_countrycode varchar(2) DEFAULT NULL,
  carddav_name varchar(64) DEFAULT NULL,
  PRIMARY KEY (contact_id)
);

-- ----------------------------------------------------------------------------
-- @constraint FK_META_GENERIC_OBJECTS_SOURCES
-- @table META_GENERIC_OBJECTS
-- ----------------------------------------------------------------------------
-- DROP CONSTRAINT FK_META_GENERIC_OBJECTS_SOURCES;

ALTER TABLE META_GENERIC_OBJECTS
	ADD CONSTRAINT IF NOT EXISTS FK_META_GENERIC_OBJECTS_SOURCES
	FOREIGN KEY (SOURCE_NAME) 
	REFERENCES META_SOURCES(NAME)
	ON DELETE CASCADE
	;

-- ----------------------------------------------------------------------------
-- @constraint FK_META_GENERIC_OBJECT_TYPES
-- @table META_GENERIC_OBJECTS
-- ----------------------------------------------------------------------------

ALTER TABLE META_GENERIC_OBJECTS
	ADD CONSTRAINT IF NOT EXISTS FK_META_GENERIC_OBJECT_TYPES
	FOREIGN KEY (OBJECT_TYPE_NAME) 
	REFERENCES META_OBJECT_TYPES(NAME)
	ON DELETE CASCADE
	;

-- ----------------------------------------------------------------------------
-- NEW COLUMN 
-- @table META_GENERIC_OBJECTS
-- ----------------------------------------------------------------------------
ALTER TABLE META_GENERIC_OBJECTS
	ADD COLUMN IF NOT EXISTS OBJECT_SOURCE_ID  VARCHAR(320) NOT NULL;
-- ----------------------------------------------------------------------------
-- @constraint FK_META_GENERIC_OBJECT_CATEGORIES_GENERIC_OBJECTS
-- @table META_GENERIC_OBJECT_CATEGORIES
-- ----------------------------------------------------------------------------

-- ----------------------------------------------------------------------------
-- NEW COLUMN 
-- @table META_GENERIC_OBJECTS
-- ----------------------------------------------------------------------------
ALTER TABLE META_GENERIC_OBJECTS
	ADD COLUMN IF NOT EXISTS OBJECT_ADDITIONAL_ID1  VARCHAR(320) NULL;
-- ----------------------------------------------------------------------------
-- @constraint FK_META_GENERIC_OBJECT_CATEGORIES_GENERIC_OBJECTS
-- @table META_GENERIC_OBJECT_CATEGORIES
-- ----------------------------------------------------------------------------

-- ----------------------------------------------------------------------------
-- NEW COLUMN 
-- @table META_GENERIC_OBJECTS
-- ----------------------------------------------------------------------------
ALTER TABLE META_GENERIC_OBJECTS
	ADD COLUMN IF NOT EXISTS OBJECT_ADDITIONAL_ID2  VARCHAR(320) NULL;
-- ----------------------------------------------------------------------------
-- @constraint FK_META_GENERIC_OBJECT_CATEGORIES_GENERIC_OBJECTS
-- @table META_GENERIC_OBJECT_CATEGORIES
-- ----------------------------------------------------------------------------
ALTER TABLE META_GENERIC_OBJECT_CATEGORIES
	ADD CONSTRAINT IF NOT EXISTS FK_META_GENERIC_OBJECT_CATEGORIES_GENERIC_OBJECTS
	FOREIGN KEY (
		OBJECT_TYPE_NAME--,
		--OBJECT_ENTITY_ID
		) 
	REFERENCES META_GENERIC_OBJECTS(
		OBJECT_TYPE_NAME--,
		--OBJECT_ENTITY_ID
		)
	ON DELETE CASCADE
	;

-- ----------------------------------------------------------------------------
-- @constraint FK_META_GENERIC_OBJECT_CATEGORIES_CATEGORIES
-- @table META_GENERIC_OBJECT_CATEGORIES
-- ----------------------------------------------------------------------------

ALTER TABLE META_GENERIC_OBJECT_CATEGORIES
	ADD CONSTRAINT IF NOT EXISTS FK_META_GENERIC_OBJECT_CATEGORIES_CATEGORIES
	FOREIGN KEY (
		CATEGORY_NAME
		) 
	REFERENCES META_CATEGORIES(
		NAME
		)
	ON DELETE CASCADE
	;

ALTER TABLE META_CATEGORIES
	ADD COLUMN IF NOT EXISTS SOURCE_ID BIGINT NOT NULL;

ALTER TABLE META_CATEGORIES
	ADD COLUMN IF NOT EXISTS SOURCE_TYPE VARCHAR(255) NOT NULL;

ALTER TABLE META_CATEGORIES
	ADD COLUMN IF NOT EXISTS TARGET_ID BIGINT NOT NULL;

ALTER TABLE META_CATEGORIES
	ADD COLUMN IF NOT EXISTS TARGET_TYPE VARCHAR(255) NOT NULL;
--	;
-- ----------------------------------------------------------------------------
-- @constraint FK_META_GENERIC_OBJECT_CATEGORIES_CATEGORIES
-- @table META_GENERIC_OBJECT_CATEGORIES
-- ----------------------------------------------------------------------------

CREATE OR REPLACE VIEW VIEW_META_GENERIC_OBJECT_CATEGORIES AS
SELECT 
	mgo.ID
		AS OBJECT_ID,
	mgo.OBJECT_ENTITY_ID
		AS ENTITY_ID,
	mgo.OBJECT_TYPE_NAME
		AS ENTITY_TYPE,
	mgo.SOURCE_NAME
		AS SOURCE_NAME,
	mgo.SOURCE_GENERATOR
		AS SOURCE_GENERATOR,
	mgo.STATUS
		AS STATUS,
	mgoc.CATEGORY_NAME
		AS CATEGORY
	FROM
		META_GENERIC_OBJECTS mgo 
		JOIN META_GENERIC_OBJECT_CATEGORIES mgoc ON 
			mgoc.OBJECT_TYPE_NAME = mgo.OBJECT_TYPE_NAME 
			AND 
			mgoc.OBJECT_ENTITY_ID = mgo.OBJECT_ENTITY_ID
			;
